==> SoMaJo-1.4.2.tar.gz: SoMaJo-1.4.2/somajo/sentence_splitter.py <==
#!/usr/bin/env python3

import regex as re


class SentenceSplitter(object):
    def __init__(self, is_tuple=False):
        """Create a SentenceSplitter object. If the tokenized paragraphs
        contain token classes or extra info, set is_tuple=True.

        """
        self.is_tuple = is_tuple
        # full stop, ellipsis, exclamation and question marks
        self.sentence_ending_punct = re.compile(r"^(?:\.+|…+\.*|[!?]+)$")
        self.opening_punct = re.compile(r"^(?:['\"¿¡\p{Pi}\p{Ps}–—]|-{2,})$")
        self.closing_punct = re.compile(r"^(?:['\"“\p{Pf}\p{Pe}])$")

    def split(self, tokenized_paragraph):
        """Split tokenized_paragraph into sentences."""
        sentence_boundaries = []
        paragraph_length = len(tokenized_paragraph)
        tokens = tokenized_paragraph
        # closing* opening* upper
        if self.is_tuple:
            tokens = [t[0] for t in tokenized_paragraph]
        for i, token in enumerate(tokens):
            if self.sentence_ending_punct.search(token):
                last = None
                boundary = i + 1
                for j in range(i + 1, paragraph_length):
                    token_j = tokens[j]
                    if token_j[0].isupper():
                        sentence_boundaries.append(boundary)
                        break
                    elif self.opening_punct.search(token_j):
                        last = "opening"
                    elif self.closing_punct.search(token_j) and last != "opening":
                        boundary = j + 1
                        last = "closing"
                    else:
                        break
        return [tokenized_paragraph[i:j] for i, j in zip([0] + sentence_boundaries, sentence_boundaries + [paragraph_length])]

==> SoMaJo-1.4.4.tar.gz: SoMaJo-1.4.4/somajo/sentence_splitter.py <==
#!/usr/bin/env python3

import regex as re


class SentenceSplitter(object):
    def __init__(self, is_tuple=False):
        """Create a SentenceSplitter object. If the tokenized paragraphs
        contain token classes or extra info, set is_tuple=True.

        """
        self.is_tuple = is_tuple
        # full stop, ellipsis, exclamation and question marks
        self.sentence_ending_punct = re.compile(r"^(?:\.+|…+\.*|[!?]+)$")
        self.opening_punct = re.compile(r"^(?:['\"¿¡\p{Pi}\p{Ps}–—]|-{2,})$")
        self.closing_punct = re.compile(r"^(?:['\"“\p{Pf}\p{Pe}])$")

    def split(self, tokenized_paragraph):
        """Split tokenized_paragraph into sentences."""
        sentence_boundaries = []
        paragraph_length = len(tokenized_paragraph)
        tokens = tokenized_paragraph
        # closing* opening* upper
        if self.is_tuple:
            tokens = [t[0] for t in tokenized_paragraph]
        for i, token in enumerate(tokens):
            if self.sentence_ending_punct.search(token):
                last = None
                boundary = i + 1
                for j in range(i + 1, paragraph_length):
                    token_j = tokens[j]
                    if token_j[0].isupper():
                        sentence_boundaries.append(boundary)
                        break
                    elif self.opening_punct.search(token_j) and token_j != "“":
                        last = "opening"
                    elif self.closing_punct.search(token_j) and last != "opening":
                        boundary = j + 1
                        last = "closing"
                    else:
                        break
        return [tokenized_paragraph[i:j] for i, j in zip([0] + sentence_boundaries, sentence_boundaries + [paragraph_length])]
